@@ -1,5 +1,5 @@
 package Text::Hspell;
-$Text::Hspell::VERSION = '0.2.5';
+$Text::Hspell::VERSION = '0.4.0';
 use 5.014;
 use strict;
 use warnings;
@@ -12,7 +12,7 @@ use vars qw(@ISA);
 
 bootstrap Text::Hspell $VERSION;
 
-use Encode qw/ encode /;
+use Encode qw/ decode encode /;
 
 sub new
 {
@@ -25,6 +25,17 @@ sub check_word
     return $self->check_word_internal( encode( 'iso8859-8', $s ) );
 }
 
+sub try_to_correct_word
+{
+    my ( $self, $s ) = @_;
+    my $ret = $self->trycorrect_internal( encode( 'iso8859-8', $s ) );
+    foreach my $r (@$ret)
+    {
+        $r = decode( 'iso8859-8', $r );
+    }
+    return $ret;
+}
+
 1;
 
 __END__
@@ -39,7 +50,7 @@ Text::Hspell - wrapper for the hspell (= Hebrew speller) library
 
 =head1 VERSION
 
-version 0.2.5
+version 0.4.0
 
 =head1 SYNOPSIS
 
@@ -66,6 +77,13 @@ Create a new speller object instance.
 Returns true if the word is spelled right and false if it is an unknown
 word.
 
+=head2 my $array_ref = $speller->try_to_correct_word($word)
+
+Returns an array reference of strings with spell correction suggestions
+for $word .
+
+(Added in version 0.4.0 .)
+
 =head2 $speller->proto_new()
 
 For internal use.
@@ -74,6 +92,10 @@ For internal use.
 
 For internal use.
 
+=head2 $speller->trycorrect_internal()
+
+For internal use.
+
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2019 by Shlomi Fish.
